var NAVTREEINDEX22 =
{
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01short_01_4.html":[6,0,0,2,2,36],
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01char_01_4.html":[6,0,0,2,2,37],
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01int_01_4.html":[6,0,0,2,2,38],
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01long_01_4.html":[6,0,0,2,2,39],
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01short_01_4.html":[6,0,0,2,2,40],
"structviennacl_1_1enable__if.html":[6,0,0,26],
"structviennacl_1_1enable__if.html#afe704250b80e0dbe82e4cb88d97a91fa":[6,0,0,26,0],
"structviennacl_1_1gibbs__poole__stockmeyer__tag.html":[6,0,0,28],
"structviennacl_1_1is__addition.html":[6,0,0,34],
"structviennacl_1_1is__addition.html#a56a038d17281b27c73786691a92b2d6ca133fd8c606baef6e69c8dfd32c0e7679":[6,0,0,34,0],
"structviennacl_1_1is__any__dense__matrix.html":[6,0,0,35],
"structviennacl_1_1is__any__dense__matrix.html#a2a89606bed6b9a80c2759395b18dfdd7a8514034ffc990147eee074fd70cd45ee":[6,0,0,35,0],
"structviennacl_1_1is__any__dense__structured__matrix.html":[6,0,0,36],
"structviennacl_1_1is__any__dense__structured__matrix.html#a8c03aae49ffb9afd56393737dfb59b2fa6e4be276ba05e38dc4e878cf61d2e290":[6,0,0,36,0],
"structviennacl_1_1is__any__scalar.html":[6,0,0,37],
"structviennacl_1_1is__any__scalar.html#a49c776d64bf6d9f94dfe5e20101fc16ea8bd5c5cfe9771c67304680cd33b18019":[6,0,0,37,0],
"structviennacl_1_1is__any__sparse__matrix.html":[6,0,0,38],
"structviennacl_1_1is__any__sparse__matrix.html#a47d05f739fd9e17e23f41fbcd4f4493aab3f46632b8a49e805b9b45fe730399b4":[6,0,0,38,0],
"structviennacl_1_1is__any__vector.html":[6,0,0,39],
"structviennacl_1_1is__any__vector.html#adbde483e9d6fa1277fae0cf8ee4194f1aeeeaecf9f88daedf39a2088cb41735d0":[6,0,0,39,0],
"structviennacl_1_1is__circulant__matrix.html":[6,0,0,40],
"structviennacl_1_1is__circulant__matrix.html#a6078350271f6e6c4f619bacad99a9f65a32e6409df4e55784e67ad65a59ead897":[6,0,0,40,0],
"structviennacl_1_1is__compressed__matrix.html":[6,0,0,41],
"structviennacl_1_1is__compressed__matrix.html#ac14d3c7524a9268c3daf8b2498c1e219a4631f18fa3e218084dfc23a63156556a":[6,0,0,41,0],
"structviennacl_1_1is__coordinate__matrix.html":[6,0,0,42],
"structviennacl_1_1is__coordinate__matrix.html#ac9a7f2aab1fe15ff8be03df6cd1b037baf6b369f957a0bc8d5953aa8decc5fcb3":[6,0,0,42,0],
"structviennacl_1_1is__cpu__scalar.html":[6,0,0,43],
"structviennacl_1_1is__cpu__scalar.html#a4c84d3ba9dacbabe9c5991b9768f5f6bad27f7b648ee3a8fc7f7488ee5b053ad2":[6,0,0,43,0],
"structviennacl_1_1is__division.html":[6,0,0,44],
"structviennacl_1_1is__division.html#af7dd39a2e59759b8af8af4e78b5435e6a7b778c7c6182b6d7b4bee026918e46e4":[6,0,0,44,0],
"structviennacl_1_1is__eigen.html":[6,0,0,45],
"structviennacl_1_1is__eigen.html#a149d07efd4817f898a691e1083a7da78a2fb1e01ec75b50cd4727e84b15cd0384":[6,0,0,45,0],
"structviennacl_1_1is__ell__matrix.html":[6,0,0,46],
"structviennacl_1_1is__ell__matrix.html#a943c1aea30b1dd1e9f887f6d0958fc19a8b8421c98fa8bd5c21c0e2de6ba9af6e":[6,0,0,46,0],
"structviennacl_1_1is__flip__sign__scalar.html":[6,0,0,47],
"structviennacl_1_1is__flip__sign__scalar.html#ad8ce9e3d6fba4b7080f6a2f87d3f2795abb5079ea832bfce7d1a1f84d7466ed4c":[6,0,0,47,0],
"structviennacl_1_1is__hankel__matrix.html":[6,0,0,48],
"structviennacl_1_1is__hankel__matrix.html#a89fca5dcf8c9b74bc1a8c94f33a72c83a43ec7d7477db590611afec6c83aa6563":[6,0,0,48,0],
"structviennacl_1_1is__hyb__matrix.html":[6,0,0,49],
"structviennacl_1_1is__hyb__matrix.html#aec7dd26bc1bd6b6e741ed64f1a0317abaeb565a6f6ad12f79ec066d7925f94af1":[6,0,0,49,0],
"structviennacl_1_1is__mtl4.html":[6,0,0,50],
"structviennacl_1_1is__mtl4.html#af521036ec794e52d24cabc6f90449143a3120c238fee99c3862d729123068c014":[6,0,0,50,0],
"structviennacl_1_1is__primitive__type.html":[6,0,0,51],
"structviennacl_1_1is__primitive__type.html#a3cc1a6ab8c516260c735e5946892bf92a7cf874622a004cd7fe95bf7170a2d04e":[6,0,0,51,0],
"structviennacl_1_1is__product.html":[6,0,0,52],
"structviennacl_1_1is__product.html#ae39311c4e1d31cd37957bef66d33c136a598beba443103ae5cde321cf0ecb9abc":[6,0,0,52,0],
"structviennacl_1_1is__row__major.html":[6,0,0,53],
"structviennacl_1_1is__row__major.html#ad928efff9a1ec6793c75c4aa8f8bb4ebae860b35ea932b52341ddead1b9d4cb20":[6,0,0,53,0],
"structviennacl_1_1is__scalar.html":[6,0,0,54],
"structviennacl_1_1is__scalar.html#ab697e34a0abb39d88b7c48e71569c46bacaf26ea5d8b780be9dda668e73f95113":[6,0,0,54,0],
"structviennacl_1_1is__sliced__ell__matrix.html":[6,0,0,55],
"structviennacl_1_1is__sliced__ell__matrix.html#adc121abc6120317c529a464d95f8dc2da885a6eb782611caf5f066eb279f77006":[6,0,0,55,0],
"structviennacl_1_1is__stl.html":[6,0,0,56],
"structviennacl_1_1is__stl.html#a34005968aaeaba3a7353f4e99bc3a1b1a01a38527c739019d1630ced36c00b47b":[6,0,0,56,0],
"structviennacl_1_1is__subtraction.html":[6,0,0,57],
"structviennacl_1_1is__subtraction.html#abecbe009bf8fb2b903aea86418cf4407a7f554764bab38ed11cffd5d7e08ecb45":[6,0,0,57,0],
"structviennacl_1_1is__toeplitz__matrix.html":[6,0,0,58],
"structviennacl_1_1is__toeplitz__matrix.html#a27b6320bc0a643db4b6992671ef067e6add9904ef5b40ae5f0b13a83b8999ff88":[6,0,0,58,0],
"structviennacl_1_1is__ublas.html":[6,0,0,59],
"structviennacl_1_1is__ublas.html#ad106b65b5d449645e6b8676192e1c5caac766ac171f92e5b0756c0f17d489b9d7":[6,0,0,59,0],
"structviennacl_1_1is__vandermonde__matrix.html":[6,0,0,60],
"structviennacl_1_1is__vandermonde__matrix.html#a205929b5cbbdb075a06d31fc81503dd2a0882876a7ed51ed8119e65b7a503d846":[6,0,0,60,0],
"structviennacl_1_1is__viennacl.html":[6,0,0,61],
"structviennacl_1_1is__viennacl.html#acb59b23d3e202e8c0df9d97114462408aa8ac23ab4df340776d36bb7535c2f591":[6,0,0,61,0],
"structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2.html":[6,0,0,4,0,0,0],
"structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2_3_01double_01_4.html":[6,0,0,4,0,0,1],
"structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2_3_01double_01_4.html#a34212c29a9ed9bcab085073a35bc5649":[6,0,0,4,0,0,1,0],
"structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2_3_01float_01_4.html":[6,0,0,4,0,0,2],
"structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2_3_01float_01_4.html#a1ffb26542513415b3e4c6d27b17a8e73":[6,0,0,4,0,0,2,0],
"structviennacl_1_1linalg_1_1cuda_1_1mat__mult__matrix__index.html":[6,0,0,4,0,1],
"structviennacl_1_1linalg_1_1detail_1_1_input_data.html":[6,0,0,4,1,4],
"structviennacl_1_1linalg_1_1detail_1_1_input_data.html#a07756dd91e2e26156d9aeed0db409a28":[6,0,0,4,1,4,2],
"structviennacl_1_1linalg_1_1detail_1_1_input_data.html#a2154f0ea1ebad5caa4e971ee70273dd5":[6,0,0,4,1,4,3],
"structviennacl_1_1linalg_1_1detail_1_1_input_data.html#a2b177029d0e953d92c03879d9a222db7":[6,0,0,4,1,4,4],
"structviennacl_1_1linalg_1_1detail_1_1_input_data.html#a4b0a695a3baaf7c5253c1fc2c66b8780":[6,0,0,4,1,4,5],
"structviennacl_1_1linalg_1_1detail_1_1_input_data.html#a6499c1b954116296e5341025c0ac1ba8":[6,0,0,4,1,4,0],
"structviennacl_1_1linalg_1_1detail_1_1_input_data.html#aa46681f0c72cc05f25a50d1fd16adfd9":[6,0,0,4,1,4,1],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_large.html":[6,0,0,4,1,7],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_large.html#a2bd6104b6d1b5327b7e90187a576634d":[6,0,0,4,1,7,13],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_large.html#a3745adea20ac023ed7971e60bcc7ba77":[6,0,0,4,1,7,11],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_large.html#a3d1729c1d3e4b8d28148b82f50a38d30":[6,0,0,4,1,7,6],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_large.html#a4c7fd021f288268c8da6e426b664e91a":[6,0,0,4,1,7,4],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_large.html#a4ffbafcbff52ed21bfc0556f6a9e816d":[6,0,0,4,1,7,1],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_large.html#a695b529b3c563f2719a2334383a6e301":[6,0,0,4,1,7,0],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_large.html#a748b92a70f85cc74b516a5a8c75e1daf":[6,0,0,4,1,7,8],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_large.html#a9acb1964e7e4e3c9d3271c86d31fa6f4":[6,0,0,4,1,7,9],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_large.html#aa81a087677f95d462243a58dbb050913":[6,0,0,4,1,7,12],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_large.html#aab48d1f3f1fc63892adf79921805370f":[6,0,0,4,1,7,14],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_large.html#ad5a921d0e8c920614b037a61c621136d":[6,0,0,4,1,7,2],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_large.html#ae5bf8aead6229cd2f783ca8408c48acb":[6,0,0,4,1,7,3],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_large.html#aea98b26fcfd26a4cd4ec93f7d60dff83":[6,0,0,4,1,7,5],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_large.html#aec1a5aacddf6d20e9b26abc4a0e48e2e":[6,0,0,4,1,7,10],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_large.html#af566114b982173623dc269ea226f8016":[6,0,0,4,1,7,7],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_small.html":[6,0,0,4,1,8],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_small.html#a05a81b912f057a10e7fbe5125ebf1b7f":[6,0,0,4,1,8,4],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_small.html#a14a32d5159fdb6407c8ef91ce4bc8489":[6,0,0,4,1,8,0],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_small.html#a78fcafcb97d89a8d4a9ed105b70e166f":[6,0,0,4,1,8,5],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_small.html#a9f2ef847143e68d1b1718ada0949eaa0":[6,0,0,4,1,8,3],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_small.html#ada572d22b80ffc72108476906c35df20":[6,0,0,4,1,8,2],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_small.html#aeba7abab2c64e83f40e4bf2d21348e9b":[6,0,0,4,1,8,1],
"structviennacl_1_1linalg_1_1detail_1_1amg_1_1classcomp.html":[6,0,0,4,1,0,8],
"structviennacl_1_1linalg_1_1detail_1_1amg_1_1classcomp.html#a60375827a7fdd3975326d323570d3c6c":[6,0,0,4,1,0,8,0],
"structviennacl_1_1linalg_1_1detail_1_1op__applier.html":[6,0,0,4,1,5],
"structviennacl_1_1linalg_1_1detail_1_1op__applier.html#a3799237939a2c0b0be63f118ea0c97b3":[6,0,0,4,1,5,0],
"structviennacl_1_1linalg_1_1detail_1_1op__executor.html":[6,0,0,4,1,6],
"structviennacl_1_1linalg_1_1detail_1_1spai_1_1_compare_second.html":[6,0,0,4,1,1,2],
"structviennacl_1_1linalg_1_1detail_1_1spai_1_1_compare_second.html#a4dc003569f8ac9e1a2fc0448eb26b75d":[6,0,0,4,1,1,2,0],
"structviennacl_1_1linalg_1_1lower__tag.html":[6,0,0,4,26],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ambm__config.html":[6,0,0,4,3,0,0],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ambm__config.html#a2d45022fb157b409f800b649b547c308":[6,0,0,4,3,0,0,3],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ambm__config.html#a5cf958857eb2a201b5974db2f46468d8":[6,0,0,4,3,0,0,1],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ambm__config.html#a7a2c0d66c19102cbc2b7dd26782fcd52":[6,0,0,4,3,0,0,2],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ambm__config.html#a9b1070f298901e5077817c8939cb67f2":[6,0,0,4,3,0,0,5],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ambm__config.html#aba88f411cc69a01f2d6ffbf5710b9ca1":[6,0,0,4,3,0,0,0],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ambm__config.html#ac8924ed6f2bdfd95d658835f34dc0cb6":[6,0,0,4,3,0,0,4],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1asbs__config.html":[6,0,0,4,3,0,1],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1asbs__config.html#a1d02ac1b9ae28dd0fdb35a38f96258cf":[6,0,0,4,3,0,1,2],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1asbs__config.html#a37e4352942d0a54619364b499e73b1d3":[6,0,0,4,3,0,1,1],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1asbs__config.html#a9e32e3ebd1448d8fc9c4ae20e11c1041":[6,0,0,4,3,0,1,3],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1asbs__config.html#a9fac42b00a34a2fd36ab92e90bedabf7":[6,0,0,4,3,0,1,4],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1asbs__config.html#ae9ddd3074043292203bfe381d1b6392a":[6,0,0,4,3,0,1,0],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1bisect__kernel.html":[6,0,0,4,3,0,2],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1compressed__compressed__matrix.html":[6,0,0,4,3,0,3],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1compressed__matrix.html":[6,0,0,4,3,0,4],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1coordinate__matrix.html":[6,0,0,4,3,0,5],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ell__matrix.html":[6,0,0,4,3,0,6],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1fft.html":[6,0,0,4,3,0,7],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1hyb__matrix.html":[6,0,0,4,3,0,8],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ilu.html":[6,0,0,4,3,0,9],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1iterative.html":[6,0,0,4,3,0,10],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__element.html":[6,0,0,4,3,0,12],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__legacy.html":[6,0,0,4,3,0,13],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__solve.html":[6,0,0,4,3,0,15],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1nmf.html":[6,0,0,4,3,0,16],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1scalar.html":[6,0,0,4,3,0,18],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1sliced__ell__matrix.html":[6,0,0,4,3,0,19],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1sliced__ell__matrix_3_01_numeric_t_00_01unsigned_01int_01_4.html":[6,0,0,4,3,0,20],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1spai.html":[6,0,0,4,3,0,21],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1svd.html":[6,0,0,4,3,0,22],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__element.html":[6,0,0,4,3,0,24],
"structviennacl_1_1linalg_1_1unit__lower__tag.html":[6,0,0,4,36],
"structviennacl_1_1linalg_1_1unit__upper__tag.html":[6,0,0,4,37],
"structviennacl_1_1linalg_1_1upper__tag.html":[6,0,0,4,38],
"structviennacl_1_1ocl_1_1_d_o_u_b_l_e___p_r_e_c_i_s_i_o_n___c_h_e_c_k_e_r.html":[6,0,0,5,11],
"structviennacl_1_1ocl_1_1accelerator__tag.html":[6,0,0,5,0],
"structviennacl_1_1ocl_1_1cpu__tag.html":[6,0,0,5,6],
"structviennacl_1_1ocl_1_1default__tag.html":[6,0,0,5,7],
"structviennacl_1_1ocl_1_1error__checker.html":[6,0,0,5,13],
"structviennacl_1_1ocl_1_1gpu__tag.html":[6,0,0,5,14],
"structviennacl_1_1ocl_1_1packed__cl__uint.html":[6,0,0,5,61],
"structviennacl_1_1ocl_1_1packed__cl__uint.html#a457e1f554ae439501613c843b6dad189":[6,0,0,5,61,3],
"structviennacl_1_1ocl_1_1packed__cl__uint.html#a5f4dcdfd54664fb7859b27f3dec641c0":[6,0,0,5,61,1],
"structviennacl_1_1ocl_1_1packed__cl__uint.html#a7991987e7676fabb8d1cbc54eaa0ba01":[6,0,0,5,61,2],
"structviennacl_1_1ocl_1_1packed__cl__uint.html#ab4fed39d6fdda2db5bcb5ec29c2537d0":[6,0,0,5,61,0],
"structviennacl_1_1ocl_1_1type__to__string.html":[6,0,0,5,65],
"structviennacl_1_1one__vector.html":[6,0,0,71],
"structviennacl_1_1op__abs.html":[6,0,0,72],
"structviennacl_1_1op__acos.html":[6,0,0,73],
"structviennacl_1_1op__add.html":[6,0,0,74],
"structviennacl_1_1op__argmax.html":[6,0,0,75],
"structviennacl_1_1op__argmin.html":[6,0,0,76],
"structviennacl_1_1op__asin.html":[6,0,0,77],
"structviennacl_1_1op__assign.html":[6,0,0,78],
"structviennacl_1_1op__atan.html":[6,0,0,79],
"structviennacl_1_1op__atan2.html":[6,0,0,80],
"structviennacl_1_1op__ceil.html":[6,0,0,81],
"structviennacl_1_1op__column.html":[6,0,0,82],
"structviennacl_1_1op__cos.html":[6,0,0,83],
"structviennacl_1_1op__cosh.html":[6,0,0,84],
"structviennacl_1_1op__div.html":[6,0,0,85],
"structviennacl_1_1op__element__binary.html":[6,0,0,86],
"structviennacl_1_1op__element__cast.html":[6,0,0,87],
"structviennacl_1_1op__element__unary.html":[6,0,0,88],
"structviennacl_1_1op__eq.html":[6,0,0,89],
"structviennacl_1_1op__exp.html":[6,0,0,90],
"structviennacl_1_1op__fabs.html":[6,0,0,91],
"structviennacl_1_1op__fdim.html":[6,0,0,92],
"structviennacl_1_1op__flip__sign.html":[6,0,0,93],
"structviennacl_1_1op__floor.html":[6,0,0,94],
"structviennacl_1_1op__fmax.html":[6,0,0,95],
"structviennacl_1_1op__fmin.html":[6,0,0,96],
"structviennacl_1_1op__fmod.html":[6,0,0,97],
"structviennacl_1_1op__geq.html":[6,0,0,98],
"structviennacl_1_1op__greater.html":[6,0,0,99],
"structviennacl_1_1op__inner__prod.html":[6,0,0,100],
"structviennacl_1_1op__inplace__add.html":[6,0,0,101],
"structviennacl_1_1op__inplace__sub.html":[6,0,0,102],
"structviennacl_1_1op__leq.html":[6,0,0,103],
"structviennacl_1_1op__less.html":[6,0,0,104],
"structviennacl_1_1op__log.html":[6,0,0,105],
"structviennacl_1_1op__log10.html":[6,0,0,106],
"structviennacl_1_1op__mat__mat__prod.html":[6,0,0,107],
"structviennacl_1_1op__matrix__diag.html":[6,0,0,108],
"structviennacl_1_1op__max.html":[6,0,0,109],
"structviennacl_1_1op__min.html":[6,0,0,110],
"structviennacl_1_1op__mult.html":[6,0,0,111],
"structviennacl_1_1op__neq.html":[6,0,0,112],
"structviennacl_1_1op__norm__1.html":[6,0,0,113],
"structviennacl_1_1op__norm__2.html":[6,0,0,114],
"structviennacl_1_1op__norm__frobenius.html":[6,0,0,115],
"structviennacl_1_1op__norm__inf.html":[6,0,0,116],
"structviennacl_1_1op__pow.html":[6,0,0,117],
"structviennacl_1_1op__prod.html":[6,0,0,118],
"structviennacl_1_1op__reduce__columns.html":[6,0,0,119],
"structviennacl_1_1op__reduce__rows.html":[6,0,0,120],
"structviennacl_1_1op__reduce__vector.html":[6,0,0,121],
"structviennacl_1_1op__row.html":[6,0,0,122],
"structviennacl_1_1op__sin.html":[6,0,0,123],
"structviennacl_1_1op__sinh.html":[6,0,0,124],
"structviennacl_1_1op__sqrt.html":[6,0,0,125],
"structviennacl_1_1op__sub.html":[6,0,0,126],
"structviennacl_1_1op__tan.html":[6,0,0,127],
"structviennacl_1_1op__tanh.html":[6,0,0,128],
"structviennacl_1_1op__trans.html":[6,0,0,129],
"structviennacl_1_1op__vector__diag.html":[6,0,0,130],
"structviennacl_1_1result__of_1_1alignment.html":[6,0,0,6,0],
"structviennacl_1_1result__of_1_1alignment.html#a8568f5b82e9b4cd293e144d3d17b0d5ca9f8524cac5b3e3d4ece1d1975bef5404":[6,0,0,6,0,1],
"structviennacl_1_1result__of_1_1alignment.html#aec42d09c43a5a60b5f651f283ac358f3":[6,0,0,6,0,0],
"structviennacl_1_1result__of_1_1cl__type.html":[6,0,0,6,1],
"structviennacl_1_1result__of_1_1cl__type.html#a340db346857782e06f4eefb3934f28c9":[6,0,0,6,1,0],
"structviennacl_1_1result__of_1_1cpu__value__type.html":[6,0,0,6,2],
"structviennacl_1_1result__of_1_1cpu__value__type.html#aa015d93f419985879a7c13b09633c5c6":[6,0,0,6,2,0],
"structviennacl_1_1result__of_1_1size__type.html":[6,0,0,6,3],
"structviennacl_1_1result__of_1_1size__type.html#a35e1136e9b35cce5f26f0eaf4427dcc3":[6,0,0,6,3,0],
"structviennacl_1_1result__of_1_1value__type.html":[6,0,0,6,4],
"structviennacl_1_1result__of_1_1value__type.html#a1fccdddb6d57eaba8f19506cea2051a3":[6,0,0,6,4,0],
"structviennacl_1_1row__iteration.html":[6,0,0,131],
"structviennacl_1_1row__major.html":[6,0,0,132],
"structviennacl_1_1row__major.html#a16e67b00a2f71de63e15bb05c8ef0856":[6,0,0,132,0],
"structviennacl_1_1row__major__tag.html":[6,0,0,133],
"structviennacl_1_1scalar__vector.html":[6,0,0,144],
"structviennacl_1_1scalar__vector.html#ab1110376608b81d0b1aa4c76a0a2ef46":[6,0,0,144,0],
"structviennacl_1_1scheduler_1_1lhs__rhs__element.html":[6,0,0,7,1],
"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a004b1ebc6c30dd52c7864dac15ffdcf5":[6,0,0,7,1,5],
"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a0137a9fb11a97dc62832a72edfc2a293":[6,0,0,7,1,67],
"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a0a66d1b72140af28cf0ea82d506bcde5":[6,0,0,7,1,20],
"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a0aa9cfe0e6438394453e18cb4b2d5f88":[6,0,0,7,1,31],
"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a141b47baf5ef9c2fc1e8e1775914911b":[6,0,0,7,1,13],
"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a1518bbf03064436bbd8ebaeb27d02231":[6,0,0,7,1,37],
"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a1714016d2100f1e6c1eb08112c5548de":[6,0,0,7,1,16],
"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a1d729198a4b9c4ea8cf639984d332c68":[6,0,0,7,1,43],
"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a1f921a78e2e942208e8bc1c7ecc52401":[6,0,0,7,1,6],
"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a23d2b2c40c404c9005452d9810967293":[6,0,0,7,1,40],
"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a2634adf095e95920e6c8fa5b484cb833":[6,0,0,7,1,33],
"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a2a0432d9e22968d482b8b66058a3fbe5":[6,0,0,7,1,70],
"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a2fb5c22bfceabb819702ff1ea87f2eb0":[6,0,0,7,1,18],
"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a35fe2d6c0ef69f04ad2c94d7b10c7cdd":[6,0,0,7,1,52],
"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a3f7a03c29c0d4d79d20ef759f4fe88e2":[6,0,0,7,1,32],
"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a403714231bcd54f45438a296bfe7a631":[6,0,0,7,1,64],
"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a44882e8993eb5d47c40152868cdf5556":[6,0,0,7,1,46]
};
